//
//  ViewController.m
//  HelloKanji2Koe
//
//  Created by Yamazaki on 2017/11/29.
//  Copyright © 2017年 AQUEST. All rights reserved.
//

#import "ViewController.h"
#import "AqKanji2Koe.h"
#import "AqUsrDic.h"

@interface ViewController ()

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    // ユーザ辞書の書換えのため、辞書ファイルをアプリバンドルからLibraryフォルダにコピー
    //　ユーザ辞書の書換え不要ならアプリバンドルのままでもOK
    [self copyDicFiles];
    
    // 開発ライセンスキーのセット
    int iret = AqKanji2Koe_SetDevKey("xxx-xxx-xxx");
    // 言語処理ライブラリのインスタンス生成
    NSString *home = NSHomeDirectory();
	const char *dicDir = [[home stringByAppendingString:@"/Library"] UTF8String];
    int iErr;
    m_pAqKanji2Koe = AqKanji2Koe_Create(dicDir, &iErr);
    // ! エラー未処理　エラーのときはNULLが戻る
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (void)dealloc {
    // 言語処理ライブラリのインスタンス解放
    if(m_pAqKanji2Koe) AqKanji2Koe_Release(m_pAqKanji2Koe);
}

// Convertボタンの押下で呼び出される
- (IBAction)convert:(id)sender
{
    char cKoe[1000];
    NSString *strKanji = [kanji text];
    
    // NSString文字列をC言語文字列(Utf8)に変換
    const char *cKanji = [strKanji UTF8String];
    
    // 言語処理　漢字仮名まじり文を音声記号列に変換
    AqKanji2Koe_Convert(m_pAqKanji2Koe, cKanji, cKoe, 1000);
    
    // C言語文字列(Utf8)をNSStringに変換してテキストボックスへセット
    koe.text = [NSString stringWithCString:cKoe encoding:NSUTF8StringEncoding];
}

- (IBAction)exportUsrDic:(id)sender {
    NSString *home = NSHomeDirectory();
    const char *pathUsrDic = [[home stringByAppendingString:@"/Library/aq_user.dic"] UTF8String];
    NSString *tmp = NSTemporaryDirectory();
    const char *pathDicCsv = [[tmp stringByAppendingString:@"aq_user.csv"] UTF8String];
    
    // ユーザ辞書aq_user.dic の内容を、ファイルaq_user.csvにCSV出力
    int iret = AqUsrDic_Export(pathUsrDic, pathDicCsv);
    
    //結果のAlert表示
    UIAlertController *alert;
    if(iret==0){
        alert = [UIAlertController alertControllerWithTitle:@"Export" message:@"CSV出力完了"
                      preferredStyle:UIAlertControllerStyleAlert];
    }
    else {
        alert = [UIAlertController alertControllerWithTitle:@"Export" message:@"CSV出力失敗"
                      preferredStyle:UIAlertControllerStyleAlert];
    }
    [alert addAction:[UIAlertAction actionWithTitle:@"はい" style:UIAlertActionStyleDefault
                      handler:^(UIAlertAction *action) { [self otherButtonPushed];}]];
    [self presentViewController:alert animated:YES completion:nil];
}

- (IBAction)importUsrDic:(id)sender {
    NSString *home = NSHomeDirectory();
    const char *pathUsrDic = [[home stringByAppendingString:@"/Library/aq_user.dic"] UTF8String];
    NSString *tmp = NSTemporaryDirectory();
    const char *pathDicCsv = [[tmp stringByAppendingString:@"aq_user.csv"] UTF8String];
    
    // aq_user.csvからユーザ辞書aq_user.dic を生成
    int iret = AqUsrDic_Import(pathUsrDic, pathDicCsv);
    UIAlertController *alert;
    if(iret==0){
        alert = [UIAlertController alertControllerWithTitle:@"Import" message:@"ユーザ辞書生成完了"
                      preferredStyle:UIAlertControllerStyleAlert];
    }
    else {
        alert = [UIAlertController alertControllerWithTitle:@"Import" message:@"ユーザ辞書生成失敗"
                      preferredStyle:UIAlertControllerStyleAlert];
    }
    [alert addAction:[UIAlertAction actionWithTitle:@"はい" style:UIAlertActionStyleDefault
                      handler:^(UIAlertAction *action) { [self otherButtonPushed];}]];
    [self presentViewController:alert animated:YES completion:nil];
}

- (void)otherButtonPushed {}

// バンドル内の辞書ファイル一式をLibraryフォルダにコピー
- (void)copyDicFiles {
    NSFileManager *fm = [NSFileManager defaultManager];
    
    //Libraryフォルダに辞書ファイル(システム辞書とユーザ辞書)があるかチェック
    NSString *home = NSHomeDirectory();
    NSString *pathSysDic = [home stringByAppendingString:@"/Library/aqdic.bin"];
    NSString *pathUsrDic = [home stringByAppendingString:@"/Library/aq_user.dic"];
    if([fm fileExistsAtPath:pathSysDic] && [fm fileExistsAtPath:pathUsrDic]) return; // コピー済み
    
    //コピー
    NSString *bundle = [[NSBundle mainBundle] bundlePath];
    NSString *bdlSysDic = [bundle stringByAppendingString:@"/aq_dic/aqdic.bin"];
    NSString *bdlUsrDic = [bundle stringByAppendingString:@"/aq_dic/aq_user.dic"];
    NSError    *err = nil;
    [fm copyItemAtPath:bdlSysDic toPath:pathSysDic error:&err];
    if(err!=nil) {
        NSLog(@"%@.",[err localizedDescription]);
    }
    [fm copyItemAtPath:bdlUsrDic toPath:pathUsrDic error:&err];
    if(err!=nil) {
        NSLog(@"%@.",[err localizedDescription]);
    }
    NSLog(@"%@",pathSysDic);
}

@end
